CCL: eh_struct Struct Reference

CCL

Data Fields
eh_struct Struct Reference

## Data Fields
double | rsound
double | zeq
double | keq
double | zdrag
double | kSilk
double | rsound_approx
double | th2p7
double | alphac
double | alphab
double | betac
double | betab
double | bnode

## Field Documentation

## ◆ alphab

double eh_struct::alphab

## ◆ alphac

double eh_struct::alphac

## ◆ betab

double eh_struct::betab

## ◆ betac

double eh_struct::betac

## ◆ bnode

double eh_struct::bnode

## ◆ keq

double eh_struct::keq

## ◆ kSilk

double eh_struct::kSilk

## ◆ rsound

double eh_struct::rsound

## ◆ rsound_approx

double eh_struct::rsound_approx

## ◆ th2p7

double eh_struct::th2p7

## ◆ zdrag

double eh_struct::zdrag

## ◆ zeq

double eh_struct::zeq

The documentation for this struct was generated from the following file:

- /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_power.c